# CHANGELOG


## v0.1.0 (2025-04-03)

### Features

- Initial release
  ([`edc3a44`](https://github.com/MicaelJarniac/opengd77/commit/edc3a44989932ec59ca39fc51cdeb6beac802d59))


## v0.0.0 (2025-03-31)
